package jersey.multipart.demo.resources;

import com.sun.jersey.api.client.ClientResponse;
import com.sun.jersey.api.client.WebResource;
import com.sun.jersey.multipart.BodyPart;
import com.sun.jersey.multipart.MultiPart;
import jersey.multipart.demo.model.Project;

import javax.imageio.ImageIO;
import javax.ws.rs.core.MediaType;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.net.URL;

public class ProjectClient {
    public static void main(String[] args) throws Exception {
      final String BASE_URI = "http://localhost:9998/";

      com.sun.jersey.api.client.Client c = com.sun.jersey.api.client.Client.create();
      WebResource service = c.resource(BASE_URI);

      Project project = new Project();
      project.setName("Jersey");
      project.setDescription("Jersey is the open source, production quality, JAX-RS (JSR 311) Reference Implementation for building RESTful Web services.");
      project.setHomepage("https://jersey.dev.java.net/");
      project.setLicense("dual CDDL+GPL license");
      project.setSvnURL("https://jersey.dev.java.net/svn/jersey/trunk");

      ByteArrayOutputStream bas = new ByteArrayOutputStream();
      URL url = new URL("https://jersey.dev.java.net/images/Jersey_yellow.png");
      BufferedImage bi = ImageIO.read(url);
      ImageIO.write(bi, "png", bas);
      byte[] logo = bas.toByteArray();

      // Construct a MultiPart with two body parts
      MultiPart multiPart = new MultiPart().
        bodyPart(new BodyPart(project, MediaType.APPLICATION_XML_TYPE)).
        bodyPart(new BodyPart(logo, MediaType.APPLICATION_OCTET_STREAM_TYPE));

      // POST the request
      ClientResponse response = service.path("/project").
        type("multipart/mixed").post(ClientResponse.class, multiPart);
      System.out.println("Response Status : " + response.getEntity(String.class));
    }
  }
